# frozen_string_literal: true

require 'influxdb-client'

module Latias
  # Influxdb
  module Influxdb
    # Bucket
    module ActionBucket
      # base
      class Base
        attr_reader :url, :token, :bucket, :org, :use_ssl, :verify_mode, :precision, :query, :client

        def execute(query)
          @query = query
        end

        def call
          all_query = "from(bucket: \"#{use_value('bucket')}\") #{@query}"
          @query = ''
          @client.create_query_api.query(query: all_query, org: use_value('org'))
        end

        def client_connection
          @query = ''
          @client = InfluxDB2::Client.new(use_value('url'), use_value('token'),
                                          use_ssl: use_value('use_ssl'),
                                          verify_mode: use_value('verify_mode'),
                                          precision: InfluxDB2::WritePrecision::NANOSECOND)
          self
        end

        private

        def use_value(key)
          b = get_binding("self")
          b.eval("@#{key}") || Latias::Influxdb.configuration.send(key)
        end

        def new_command
          '|> '
        end

        def get_binding(param)
          binding
        end
      end
    end
  end
end
